@@ -34,7 +34,7 @@ describe 'oslo::cache' do
           :proxies                              => ['proxy1', 'proxy2'],
           :enabled                              => true,
           :debug_cache_backend                  => true,
-          :memcache_servers                     => ['host1:11211', 'host2:11211'],
+          :memcache_servers                     => ['host1:11211', 'host2:11211','[fd12:3456:789a:1::1]:11211'],
           :memcache_dead_retry                  => '300',
           :memcache_socket_timeout              => '3',
           :memcache_pool_maxsize                => '10',
@@ -51,7 +51,7 @@ describe 'oslo::cache' do
         is_expected.to contain_keystone_config('cache/proxies').with_value('proxy1,proxy2')
         is_expected.to contain_keystone_config('cache/enabled').with_value('true')
         is_expected.to contain_keystone_config('cache/debug_cache_backend').with_value('true')
-        is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211')
+        is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211,inet6:[fd12:3456:789a:1::1]:11211')
         is_expected.to contain_keystone_config('cache/memcache_dead_retry').with_value('300')
         is_expected.to contain_keystone_config('cache/memcache_socket_timeout').with_value('3')
         is_expected.to contain_keystone_config('cache/memcache_pool_maxsize').with_value('10')
@@ -75,6 +75,18 @@ describe 'oslo::cache' do
           :tag    => 'openstack',
         )
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-pylibmc')
+        end
+      end
     end
 
     context 'with memcache backend' do
@@ -87,11 +99,22 @@ describe 'oslo::cache' do
       it 'configures cache backend' do
         is_expected.to contain_keystone_config('cache/backend').with_value('dogpile.cache.memcache')
         is_expected.to contain_package('python-memcache').with(
-          :ensure => 'present',
           :name   => platform_params[:python_memcache_package_name],
-          :tag    => ['openstack', 'keystone-package'],
+          :tag    => ['openstack'],
         )
       end
+
+      context 'with backend package management disabled' do
+        before do
+          params.merge!({
+            :manage_backend_package => false,
+          })
+        end
+
+        it 'does not install backend package' do
+          is_expected.not_to contain_package('python-memcache')
+        end
+      end
     end
 
     context 'with string in list parameters' do
@@ -103,7 +126,7 @@ describe 'oslo::cache' do
         }
       end
 
-      it 'configures oslo_policy section with overriden list values as strings' do
+      it 'configures oslo_policy section with overridden list values as strings' do
         is_expected.to contain_keystone_config('cache/backend_argument').with_value('foo:bar')
         is_expected.to contain_keystone_config('cache/memcache_servers').with_value('host1:11211,host2:11211')
         is_expected.to contain_keystone_config('cache/proxies').with_value('proxy1,proxy2')
@@ -119,11 +142,16 @@ describe 'oslo::cache' do
         facts.merge!(OSDefaults.get_facts())
       end
       let(:platform_params) do
-        platform_params = { :pylibmc_package_name => 'python-pylibmc' }
+        case facts[:osfamily]
+        when 'Debian'
+          platform_params = { :pylibmc_package_name => 'python3-pylibmc' }
+        when 'RedHat'
+          platform_params = { :pylibmc_package_name => 'python-pylibmc' }
+        end
 
         case facts[:osfamily]
         when 'Debian'
-          platform_params[:python_memcache_package_name] = 'python-memcache'
+          platform_params[:python_memcache_package_name] = 'python3-memcache'
         when 'RedHat'
           platform_params[:python_memcache_package_name] = 'python-memcached'
         end
